# Generated by extendr: Do not edit by hand
# nolint start

#' @usage NULL
#' @useDynLib rtiktoken, .registration = TRUE
NULL

rs_get_tokens <- function(text, model) .Call(wrap__rs_get_tokens, text, model)

rs_model_to_tokenizer <- function(model) .Call(wrap__rs_model_to_tokenizer, model)

rs_get_token_count <- function(text, model) .Call(wrap__rs_get_token_count, text, model)

rs_decode_tokens <- function(tokens, model) .Call(wrap__rs_decode_tokens, tokens, model)

# nolint end
